<?php
/**
 * Control Classes for This Theme.
 * @subpackage hgwmag
 */


//  =============================================================================
//  - Custom Title Control for hgwmag theme
//  =============================================================================
class HgwMag_Custom_Title_Customizer extends WP_Customize_Control{
    // Control type
    public $type = 'hgw-custom-title';
    // Control lable
    public $label = '';
    // Control description
    public $description = '';
    // Render Content
    public function render_content(){

        echo '<h3>'. esc_html($this->label) .'</h3>';

        if (!empty($this->description)) {
           echo '<span class="customize-control-description">'. esc_html($this->description) .'</span>';
         }

    }
}



//  =============================================================================
//  - Taxonomy Select Control for hgwmag theme
//  =============================================================================
class HgwMag_Category_Dropdown_Control extends WP_Customize_Control {

    // Control type
    public $type = 'hgw_dropdown_tax';

    // Taxonomy.
    public $taxonomy = '';

    // Constructor
    public function __construct( $manager, $id, $args = array() ) {

        $our_taxonomy = 'category';
        if ( isset( $args['taxonomy'] ) ) {
            $taxonomy_exist = taxonomy_exists( $args['taxonomy']  );
            if ( true === $taxonomy_exist ) {
                $our_taxonomy =  $args['taxonomy'];
            }
        }
        $args['taxonomy'] = $our_taxonomy;
        $this->taxonomy =  $our_taxonomy;

        parent::__construct( $manager, $id, $args );
    }

    // Render Content
    public function render_content() {

        $all_taxonomies = get_categories(
          array(
              'hierarchical' => 0,
              'taxonomy'     => $this->taxonomy,
              'orderby'      => 'count',
              'order'        => 'DESC',
              'hide_empty'      => false,
          )
        );

        ?>
        <label>
            <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
            <?php
            if ( ! empty( $this->description ) ) :
                echo '<span class="description customize-control-description">'. esc_html( $this->description ) .'</span>';
            endif;
            ?>
            <select <?php $this->link(); ?>>
                <?php
                printf(
                  '<option value="%s" %s>%s</option>',
                  0,
                  selected( $this->value(), '', false ),
                  esc_html__( 'All', 'hgwmag' )
                );

                if ( ! empty( $all_taxonomies ) ) :
                    foreach ( $all_taxonomies as $key => $tax ) :

                        printf(
                          '<option value="%s" %s>%s</option>',
                          esc_attr( $tax->term_id ),
                          selected( $this->value(), $tax->term_id, false ),
                          esc_html( $tax->name .' ('. $tax->count . ')' )
                        );

                    endforeach;
                endif;
                ?>
            </select>
        </label>
        <?php
    }
}

/**
 * Custom Slider Control
 */
class HgwMag_Slider_Custom_Control extends WP_Customize_Control {

  // The type of control being rendered
  public $type = 'slider_control';
  // Default value of control being rendered
  public $default_value = '';
  // Enqueue our scripts and styles
  public function enqueue() {
    wp_enqueue_script( 'hgw-custom-controls-js', get_template_directory_uri() . '/assets/js/customizer.js', array( 'jquery', 'jquery-ui-core' ), '1.0', true );
    wp_enqueue_style( 'hgw-custom-controls-css', get_template_directory_uri() . '/assets/css/customizer.css', array(), '1.0', 'all' );
  }
  // Render the control in the customizer
  public function render_content() {
    $defaultVal = ( $this->default_value ) ? $this->default_value : $this->value() ;
  ?>
    <div class="slider-custom-control">
      <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
      <span class="slider-reset dashicons dashicons-image-rotate" slider-reset-value="<?php echo esc_attr( $defaultVal ); ?>"></span>

      <div class="slider" slider-min-value="<?php echo esc_attr( $this->input_attrs['min'] ); ?>" slider-max-value="<?php echo esc_attr( $this->input_attrs['max'] ); ?>" slider-step-value="<?php echo esc_attr( $this->input_attrs['step'] ); ?>"></div>
      <input type="number" id="<?php echo esc_attr( $this->id ); ?>" name="<?php echo esc_attr( $this->id ); ?>" value="<?php echo esc_attr( $this->value() ); ?>" class="customize-control-slider-value" <?php $this->link(); ?> />

    </div>
  <?php
  }
}
