<?php
/**
 * Sanitization Functions for This Theme.
 * @subpackage hgwmag
 */


if ( ! function_exists( 'hgwmag_sanitize_checkbox' ) ) :
//  =============================================================================
//  - Sanitize checkbox.
//  =============================================================================
function hgwmag_sanitize_checkbox( $input ) {

   return ( ( isset( $input ) && true === $input ) ? true : false );

}

endif;


if ( ! function_exists( 'hgwmag_sanitize_radio' ) ) :
  //  =============================================================================
  //  - Sanitize Radio & Select
  //  =============================================================================
function hgwmag_sanitize_radio_and_select( $input, $setting ) {

  // Ensure input is a slug.
  $input = sanitize_key( $input );
  // Get list of choices from the control associated with the setting.
  $choices = $setting->manager->get_control( $setting->id )->choices;
  // If the input is a valid key, return it; otherwise, return the default.
  return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

}

endif;


if ( ! function_exists( 'hgwmag_sanitize_decimal_number' ) ) :
  //  =============================================================================
  //  - Sanitize Decimal number
  //  =============================================================================
  function hgwmag_sanitize_decimal_number( $input, $setting ) {

    $atts = $setting->manager->get_control( $setting->id )->input_attrs;

    $min = ( isset( $atts['min'] ) ? $atts['min'] : $input );
    $max = ( isset( $atts['max'] ) ? $atts['max'] : $input );
    $step = ( isset( $atts['step'] ) ? $atts['step'] : 0.001 );

    $input = floor($input / $atts['step']) * $atts['step'];

    return ( $min <= $input && $input <= $max ) ? $input : $setting->default;
  }
endif;
