<?php
/**
* Template Tags for This Theme
* @subpackage hgwmag
*/
if ( ! function_exists( 'hgwmag_default_content' ) ) :
  /*
  #=========================================================================
  #   Default post Content
  #   Show with Function
  #   If there is no post this Function Show Default content
  #=========================================================================
  */
function hgwmag_default_content(){
  ?>
    <div class="post-box not-found">
      <div class="post">
        <p>
          <?php
          if ( is_search() ):
            echo esc_html__( 'Does not match any results. Make sure all words are spelled correctly or try different keywords.', 'hgwmag' );
          else:
            echo esc_html__( 'Sorry, there is no post yet.', 'hgwmag' );
          endif;
          ?>
        </p>
      </div>
    </div>
  <?php
}

endif;


if ( ! function_exists( 'hgwmag_default_widget_post_loop' ) ) :
  /*
  #=========================================================================
  #   Default Widget Posts
  #   Show with Function
  #   This Function Show Default Widget Posts in Sidebar
  #=========================================================================
  */
function hgwmag_default_widget_post_loop( $title, $number, $stickyPost, $orderby ){

  if ($stickyPost == true) { $PostsNotIN = ''; }
  else{ $PostsNotIN = get_option("sticky_posts"); }

  $WidgetPostsArgs = array(
    'post__not_in' => $PostsNotIN,
    'orderby' => $orderby,
    'posts_per_page' => $number,
  );

  $WidgetPosts = new WP_Query($WidgetPostsArgs);
  if ( $WidgetPosts->have_posts() ) {
    ?>
    <div class="widget">
    <h4 class="widget-title"><?php echo esc_html( $title ); ?></h4>
    <?php
    echo '<nav role="navigation"><ul>';
    while ( $WidgetPosts->have_posts() ) {
      $WidgetPosts->the_post();
      get_template_part( 'template-parts/content', 'widget' );
    }
    wp_reset_postdata();
    echo "</ul></nav>";
  }
  else {
    echo '<nav role="navigation"><ul><li class="post">'.esc_html__( 'Sorry, there is no post yet.', 'hgwmag' ).'</li></ul></nav>';
   }
  ?>
  </div>
  <?php

}

endif;


if ( ! function_exists( 'hgwmag_default_posts_loop' ) ) :
  /*
  #=========================================================================
  #   Main Loop
  #   Show with action
  #   This Function Showing main loop in fron-page, home-page, archive pages, ...
  #=========================================================================
  */
	function hgwmag_default_posts_loop(){

		if ( have_posts() ) : ?>

		  <div class="post-box-container type-3 posts-archive">

		    <?php if ( is_front_page() ): ?>

		      <h3 class="title line"><?php echo esc_html__( 'Recent Posts', 'hgwmag' ); ?></h3>

		    <?php endif; ?>


		      <div class="post-box">
		        <?php

		        while ( have_posts() ) : the_post();

		            get_template_part( 'template-parts/simple', 'excerpt' );

		        endwhile;

		        the_posts_pagination();

		        wp_reset_postdata();
		      ?>
		      </div>

		  </div>

		<?php
  else:

    hgwmag_default_content();

	endif;

	}

endif;

if ( ! function_exists( 'hgwmag_post_date' ) ) :
  /*
  #=========================================================================
  #   Publish date
  #   Show with Function
  #   This Function Show Post Date
  #=========================================================================
  */
function hgwmag_post_date() {

  $pd_format = "<i class='fa fa-clock-o' aria-hidden='true'></i>&nbsp;<time datetime='%1\$s'>%2\$s</time>";
  echo sprintf(
    $pd_format,// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
    esc_attr( get_the_date('c') ),
    esc_html( get_the_date() )
  );

}

endif;

if ( ! function_exists( 'hgwmag_post_info' ) ) :
  /*
  #=========================================================================
  #   Publish date
  #   Show with Function
  #   This Function Show Post Date
  #=========================================================================
  */
function hgwmag_post_info( $poDate = true, $poComments = true, $poAuthor = false ) {
  if ($poDate) {
    hgwmag_post_date();
  }
  if ( $poComments && get_theme_mod( 'hgwmag-disable-comments', 0 ) == 0 ) {
    ?>
    <span class="comments">
      <i class="fa fa-comment" aria-hidden="true"></i>
      <?php comments_number(); ?>
    </span>
    <?php
  }
  if ($poAuthor) {
    ?>
    <span>
      <i class="fa fa-user" aria-hidden="true"></i>
      <?php echo esc_html( get_the_author() ) ?>
    </span>
    <?php
  }

}

endif;

if ( ! function_exists( 'hgwmag_copyright' ) ) :
  /*
  #=========================================================================
  #   Copyright
  #   Show with Function
  #   This Function Show Copyright in footer
  #=========================================================================
  */
function hgwmag_copyright() {

	global $wpdb;

	$copyright_dates = $wpdb->get_results("
			SELECT
			YEAR(min(post_date_gmt)) AS firstdate,
			YEAR(max(post_date_gmt)) AS lastdate
			FROM
			$wpdb->posts
			WHERE
			post_status = 'publish'
		");

	$copyright_date_output = '';

	if($copyright_dates) {

		$copyright = "&copy; " . $copyright_dates[0]->firstdate;

		if($copyright_dates[0]->firstdate != $copyright_dates[0]->lastdate) {

			$copyright .= '-' . $copyright_dates[0]->lastdate;

		}

		$copyright_date_output = $copyright;

	}
  $copyright_format = "<p>%1\$s&nbsp;%2\$s</p><p>%3\$s&nbsp;-&nbsp;<a href='%5\$s' title='%6\$s' target='_blank'>%4\$s</a></p>";
  // sprintf();
  echo sprintf(
    $copyright_format,// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
    $copyright_date_output,// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
    esc_html( get_bloginfo('name') ),
    esc_html__( 'Powered by WordPress', 'hgwmag' ),
    esc_html( 'Hgw Magazine Theme'),
    esc_url( 'https://hamgamweb.com/themes/hgwmag/', 'hgwmag' ),
    esc_attr__( 'Hamgamweb', 'hgwmag' )
  );

}

endif;


if ( ! function_exists( 'hgwmag_footer' ) ) :
  /*
  #=========================================================================
  #   Footer
  #   Show with Function
  #   This Function Show Copyright in footer
  #=========================================================================
  */
function hgwmag_footer() {
?>

<footer id="site-footer" class="header-footer-group">

  <div class="innerw">
    <div class="inner-section flex-sb">
      <div class="ft-brand">
        <div class="description">
          <h4 class="title line">
            <?php
            if ( !empty( get_theme_mod('hgwmag_footer_title_c1' ) ) ):
              echo esc_html( get_theme_mod('hgwmag_footer_title_c1' ) );
            else:
              esc_html( bloginfo('name') );
            endif;
            ?>
          </h4>
          <p>
            <?php
            if ( !empty( get_theme_mod('hgwmag_footer_description' ) ) ):
              echo esc_html( get_theme_mod('hgwmag_footer_description' ) );
            else:
              esc_html( bloginfo('description') );
            endif;
            ?>
          </p>
        </div>
        <?php if ( get_theme_mod('hgwmag_footer_social_media', 1 ) == 1 ): ?>
          <div class="social">
            <h4 class="title line"><?php esc_html_e( 'Follow us', 'hgwmag' ) ?></h4>
            <?php hgwmag_social_media_pages(); ?>
          </div>
        <?php endif; ?>

      </div>
      <div class="ft-widget">
        <?php
          if ( is_active_sidebar( 'footer-area1' ) ) {
            dynamic_sidebar('footer-area1');
          }else{
            hgwmag_default_widget_post_loop( 'Recent Posts', 3, false, '' );
          }
         ?>
      </div>
      <div class="ft-widget">
        <?php
          if ( is_active_sidebar( 'footer-area2' ) ) {
            dynamic_sidebar('footer-area2');
          }else{
            if ( get_theme_mod( 'hgwmag-disable-comments', 0 ) == 0 ) {
              hgwmag_default_widget_post_loop( 'Most Comments', 3, false, 'comment_count' );
            }else{
              hgwmag_default_widget_post_loop( 'Suggested', 3, false, 'rand' );
            }
          }
         ?>
      </div>
    </div>
  </div>

  <div class="copyright">
    <div class="innerw">
      <div class="inner-copyright">
        <?php hgwmag_copyright() ?>
      </div>
    </div>
  </div>

  <a href="#site-header" id="scroll-up" class="scrollup">
    <i class="fa fa-angle-up" aria-hidden="true"></i>
  </a>

</footer><!-- #site-footer -->

<?php
}

endif;
